@@ -38,7 +38,7 @@ CSS = """
     font-size: 125%;
 }
 .nbae-question .score::before {
-    content: "⎯⎯";
+    content: "|";
     align-self: center;
     margin-right: 10px;
 }
@@ -51,6 +51,10 @@ CSS = """
     line-height: 1.3;
     padding: 5px;
 }
+.nbae-question hr {
+    height: 1px;
+    background-color: #202020;
+}
 .nbae-question .code {
     border: 1px solid #aaa;
 }
@@ -92,6 +96,7 @@ CSS = """
 
 .nbae-quiz .wrong-answer {
     background-color: #ff2e63;
+    border-radius: 6px;
 }
 
 .nbae-quiz .final {
